//
//  View.swift
//  Tap
//
//  Created by Mark Meretzky on 7/19/16.
//  Copyright © 2016 Mark Meretzky. All rights reserved.
//

import UIKit

class View: UILabel {

	//Nanoseconds until the display goes back to "0".
	//One nanosecond is a billionth of a second.
	let delay: Int64 = 3500000000;	//3.5 seconds
	
	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder)!;
		
		font = UIFont.systemFontOfSize(bounds.size.height);
		textAlignment = NSTextAlignment.Center;
		wearOff();
		
		let singleRecognizer: UITapGestureRecognizer =
			UITapGestureRecognizer(target: self, action: #selector(singleAction(_:)));
		singleRecognizer.numberOfTapsRequired = 1;
		
		let doubleRecognizer: UITapGestureRecognizer =
			UITapGestureRecognizer(target: self, action: #selector(doubleAction(_:)));
		doubleRecognizer.numberOfTapsRequired = 2;
		
		//Don't call singleAction(_:) until we know for sure
		//that this tap is not the first tap of a double tap.
		singleRecognizer.requireGestureRecognizerToFail(doubleRecognizer);
		
		addGestureRecognizer(singleRecognizer);
		addGestureRecognizer(doubleRecognizer);
	}
	
	func singleAction(recognizer: UITapGestureRecognizer) -> Void {
		text = "1";
		let t: dispatch_time_t = dispatch_time(DISPATCH_TIME_NOW, delay);
		dispatch_after(t, dispatch_get_main_queue(), wearOff);
	}
	
	func doubleAction(recognizer: UITapGestureRecognizer) -> Void {
		text = "2";
		let t: dispatch_time_t = dispatch_time(DISPATCH_TIME_NOW, delay);
		dispatch_after(t, dispatch_get_main_queue(), wearOff);
	}
	
	func wearOff() -> Void {
		text = "0";
	}

	/*
	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.
	override func drawRect(rect: CGRect) {
		// Drawing code
	}
	*/

}
